summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qcanvas_imp.h
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/qtbindings/qcanvas_imp.h')
-rw-r--r--kjsembed/qtbindings/qcanvas_imp.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/kjsembed/qtbindings/qcanvas_imp.h b/kjsembed/qtbindings/qcanvas_imp.h
index 255bbe44..fd91b3ba 100644
--- a/kjsembed/qtbindings/qcanvas_imp.h
+++ b/kjsembed/qtbindings/qcanvas_imp.h
@@ -9,7 +9,7 @@
#include <kjsembed/jsobjectproxy_imp.h>
-class TQCanvas;
+class TTQCanvas;
/**
* Namespace containing the KJSEmbed library.
@@ -17,11 +17,11 @@ class TQCanvas;
namespace KJSEmbed {
/**
* Wrapper class for TQCanvas methods.
*
* @author Richard Moore, rich@kde.org
*/
-class QCanvasImp : public JSProxyImp
+class TQCanvasImp : public JSProxyImp
{
public:
/** Enumerates the constructors supported by this class. */
@@ -87,8 +87,8 @@ public:
Method_Last = -1
};
- QCanvasImp( KJS::ExecState *exec, int id, bool constructor=false );
- ~QCanvasImp();
+ TQCanvasImp( KJS::ExecState *exec, int id, bool constructor=false );
+ ~TQCanvasImp();
/**
* Adds the static bindings for this class to the specified Object. The
@@ -102,15 +102,15 @@ public:
*/
static void addBindings( KJS::ExecState *exec, KJS::Object &object );
- static TQCanvas *toQCanvas( KJS::Object &object );
+ static TTQCanvas *toTQCanvas( KJS::Object &object );
//
// Constructors implemented by this class.
//
- KJS::Object QCanvas_1( KJS::ExecState *exec, const KJS::List &args );
- KJS::Object QCanvas_2( KJS::ExecState *exec, const KJS::List &args );
- KJS::Object QCanvas_3( KJS::ExecState *exec, const KJS::List &args );
+ KJS::Object TQCanvas_1( KJS::ExecState *exec, const KJS::List &args );
+ KJS::Object TQCanvas_2( KJS::ExecState *exec, const KJS::List &args );
+ KJS::Object TQCanvas_3( KJS::ExecState *exec, const KJS::List &args );
//
// Methods implemented by this class.
@@ -182,7 +182,7 @@ public:
virtual KJS::Value call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args );
private:
- TQCanvas *instance; // Temp
+ TTQCanvas *instance; // Temp
int id;
bool cons;
};
@@ -17,11 +17,11 @@ class TQCanvas;
namespace KJSEmbed {
/**
- * Wrapper class for TQCanvas methods.
+ * Wrapper class for TTQCanvas methods.
*
* @author Richard Moore, rich@kde.org